summaryrefslogtreecommitdiff
path: root/src/mongo/db/clientcursor.h
diff options
context:
space:
mode:
authorBernard Gorman <bernard.gorman@gmail.com>2018-02-02 16:02:30 +0000
committerBernard Gorman <bernard.gorman@gmail.com>2018-02-13 11:04:43 +0000
commit1221b80ee0d65879a4c76ff98f78e92b53766cc0 (patch)
treea6e4f81b3a82160ba3663daa4e4eaac07fad652e /src/mongo/db/clientcursor.h
parentca0a855dfc0f479d85b76a640b12a259c0547310 (diff)
downloadmongo-1221b80ee0d65879a4c76ff98f78e92b53766cc0.tar.gz
SERVER-32912 Ensure that killCursors always invalidates a pinned cursor
Diffstat (limited to 'src/mongo/db/clientcursor.h')
-rw-r--r--src/mongo/db/clientcursor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/clientcursor.h b/src/mongo/db/clientcursor.h
index f6a97bfe4c9..f0f8772df73 100644
--- a/src/mongo/db/clientcursor.h
+++ b/src/mongo/db/clientcursor.h
@@ -268,10 +268,10 @@ private:
~ClientCursor();
/**
* Marks this cursor as killed, so any future uses will return an error status including
* 'reason'.
*/
- void markAsKilled(const std::string& reason);
+ void markAsKilled(Status killStatus);
/**
* Disposes this ClientCursor's PlanExecutor. Must be called before deleting a ClientCursor to
@@ -268,10 +268,10 @@ private:
~ClientCursor();
/**
- * Marks this cursor as killed, so any future uses will return an error status including
- * 'reason'.
+ * Marks this cursor as killed, so any future uses will return 'killStatus'. It is an error to
+ * call this method with Status::OK.
*/